Learn R Programming

diagonals (version 0.3.0)

fatdiag: Fat Matrix Diagonals

Description

Fat Matrix Diagonals

fatdiag set

Usage

fatdiag(x = 1, steps = NULL, size = NULL, nrow = NULL, ncol = NULL)

fatdiag(x, steps = NULL, size = NULL, on_diagonal = TRUE) <- value

Arguments

x
a matrix where the dimensions are integer multiples of size or integer dividors of steps
steps
the required number of steps (block matrices) across the diagonal
size
the width or height of the matrix being dropped over the diagonal of matrix x
nrow
the number of rows
ncol
the number of columns
on_diagonal
should the operation be apply to the elements on the fat diagonal.
value
replacement value

Functions

  • fatdiag<-: the set version of fatdiag

Details

Either steps or size is expected to be provided.