Usage
matricise(x, row_dim = c(NULL, 3, 4), col_dim = c(NULL, 3, 4))
Arguments
x
a higher-order array (length(dim(x)) >= 3)
row_dim
the input array dimension which should be added to the row dimension of the output matrix, the value has to be 3 or 4.
col_dim
the input array dimension which should be added to the column dimension of the output matrix, the value has to be 3 or 4.
Value
a matrix (length(dim(x)) == 2 )